@@ -22,7 +22,43 @@ import matplotlib.pyplot as plt
 from scipy import stats
 import pandas as pd
 from sklearn.preprocessing import minmax_scale
-import keras
+
+
+# label转one-hot
+def to_categorical(label, num_classes=None):
+    '''
+    :param label: 样本标签
+    :param num_classes: 总共的类别数
+    :return: 标签的one-hot编码
+    '''
+    label = np.array(label, dtype='int')
+    if num_classes is not None:
+        assert num_classes > label.max()  # 类别数量错误
+    else:
+        num_classes = label.max() + 1
+    if len(label.shape) == 1:
+        y = np.eye(num_classes, dtype='int64')[label]
+        return y
+    elif len(label.shape) == 2 and label.shape[1] == 1:
+        y = np.eye(num_classes, dtype='int64')[label.squeeze()]
+        return y
+    else:
+        warnings.warn('Warning: one_hot_to_label do not work')
+        return label
+
+
+# one-hot转label
+def one_hot_to_label(y):
+    '''
+    :param y: one-hot编码
+    :return: 标签
+    '''
+    y = np.array(y)
+    if len(y.shape) == 2 and y.max() == 1 and y.sum(1).mean() == 1:
+        return y.argmax(1)
+    else:
+        warnings.warn('Warning: one_hot_to_label do not work')
+        return y
 
 
 # 生成样本
@@ -39,7 +75,7 @@ def generate_sample(x, y, N_classes=None, sample_num=None, have_correct=True):
     if N_classes is None:
         N_classes = y.max() + 1
     if len(y.shape) == 1:
-        y = keras.utils.to_categorical(y, N_classes)
+        y = to_categorical(y, N_classes)
     if sample_num is None:
         sample_num = N_classes
     assert sample_num > 0  # 生成的样本必须大于0个
@@ -84,43 +120,6 @@ def data_iter(data, label, batch_size, is_True=None):
             yield np.take(data, j, 0), np.take(label, j, 0)
 
 
-# label转one-hot
-def to_categorical(label, num_classes=None):
-    '''
-    :param label: 样本标签
-    :param num_classes: 总共的类别数
-    :return: 标签的one-hot编码
-    '''
-    label = np.array(label, dtype='int')
-    if num_classes is not None:
-        assert num_classes > label.max()  # 类别数量错误
-    else:
-        num_classes = label.max() + 1
-    if len(label.shape) == 1:
-        y = np.eye(num_classes, dtype='int64')[label]
-        return y
-    elif len(label.shape) == 2 and label.shape[1] == 1:
-        y = np.eye(num_classes, dtype='int64')[label.squeeze()]
-        return y
-    else:
-        warnings.warn('Warning: one_hot_to_label do not work')
-        return label
-
-
-# one-hot转label
-def one_hot_to_label(y):
-    '''
-    :param y: one-hot编码
-    :return: 标签
-    '''
-    y = np.array(y)
-    if len(y.shape) == 2 and y.max() == 1 and y.sum(1).mean() == 1:
-        return y.argmax(1)
-    else:
-        warnings.warn('Warning: one_hot_to_label do not work')
-        return y
-
-
 # 画出样本数据示意图
 def plot(x, y, method='t-SNE'):
     '''
@@ -146,7 +145,7 @@ def plot(x, y, method='t-SNE'):
 
 
 # 画出分类边界图
-def plot_classifier(classifier, x, y, method='pca', figsize=None, save_path=None, show=True):
+def plot_classifier(classifier, x, y, method='tsne', figsize=None, save_path=None, show=True):
     '''
     :param classifier: 分类器
     :param x: 数据
@@ -158,6 +157,7 @@ def plot_classifier(classifier, x, y, method='pca', figsize=None, save_path=None
     :return: None
     '''
 
+    method = method.lower()
     if x.shape[1] > 2:
         if method == 'tsne':
             x = TSNE(2).fit_transform(x)
@@ -190,6 +190,7 @@ def plot_classifier(classifier, x, y, method='pca', figsize=None, save_path=None
         plt.savefig(fname=save_path, bbox_inches='tight', dpi=300)
     if show:
         plt.show()
+    plt.close()
 
 
 # def plot_classifier(classifier, x, y, axes=[-1.5, 2.5, -1, 1.5]):
